@@ -24,8 +24,8 @@ size_t R_curl_read_buffer_callback(void *ptr, size_t size, size_t nmemb, void *s
 typedef struct BufInfo {
     size_t length;
     size_t pos;
-    void *buf;
-    void *cur;
+    char *buf;
+    char *cur;
 } BufInfo;
 
 void * getCurlPointerForData(SEXP el, CURLoption option, Rboolean isProtected, CURL *handle);
@@ -1420,7 +1420,7 @@ getRStringsFromNullArray(const char * const *d)
 
 
 #if 0
-char *DefaultURL = "http://www.omegahat.org/index.html";
+char *DefaultURL = "http://www.omegahat.net/index.html";
 void
 R_test_curl(void)
 {
